@@ -42,11 +42,7 @@ from airflow.providers.microsoft.azure.utils import (
     get_field,
     get_sync_default_azure_credential,
 )
-
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.microsoft.azure.version_compat import BaseHook
 
 if TYPE_CHECKING:
     import datetime
@@ -523,7 +519,7 @@ class MessageHook(BaseAzureServiceBusHook):
         message_creator: Callable[[str], ServiceBusMessage],
     ):
         list_messages = [message_creator(body) for body in messages]
-        sender.send_messages(list_messages)  # type: ignore[arg-type]
+        sender.send_messages(list_messages)
 
     @staticmethod
     def send_batch_message(
